@@ -15,7 +15,7 @@ class DataPackageServerConstants:
         self.HTTPDEBUG = False
         self.HTTPMETHODS = ['POST', 'GET', 'PUT']
         self.IP = "0.0.0.0"
-        self.versionInfo = 'FreeTAKServer-0.8.76-Beta'
-        self.NodeID = 'Public-FTS'
+        self.versionInfo = 'FreeTAKServer-0.9.09-Beta'
+        self.NodeID = 'FTS'
         self.VERSIONJSON = '{"version":"2","type":"ServerConfig", "data":{"version": "%s", "api": "2","hostname":"%s"}, "nodeId":"%s"}' % (
             self.versionInfo, "0.0.0.0", self.NodeID)
